@@ -61,7 +61,7 @@ GlossaryView::GlossaryView(QWidget* parent, Catalog* catalog, const QVector<QAct
     , m_catalog(catalog)
     , m_flowLayout(new FlowLayout(FlowLayout::glossary,/*who gets signals*/this, actions, 0, 10))
     , m_glossary(Project::instance()->glossary())
-    , m_rxClean(Project::instance()->markup() % '|' % Project::instance()->accel()) //cleaning regexp; NOTE isEmpty()?
+    , m_rxClean(Project::instance()->markup() + '|' + Project::instance()->accel()) //cleaning regexp; NOTE isEmpty()?
     , m_rxSplit(QStringLiteral("\\W|\\d"))//splitting regexp
     , m_currentIndex(-1)
     , m_normTitle(i18nc("@title:window", "Glossary"))
